@@ -5,7 +5,7 @@ import requests
 import numpy as np
 import torch
 
-from lightwood.encoders.time_series.ts_fresh_ts import TsFreshTsEncoder
+from lightwood.encoders.time_series.rnn import RnnEncoder
 from lightwood.encoders.encoder_base import BaseEncoder
 from lightwood.logger import log
 
@@ -14,7 +14,7 @@ class AmplitudeTsEncoder(BaseEncoder):
 
     def __init__(self, is_target=False):
         super().__init__(is_target)
-        self._ts_encoder = TsFreshTsEncoder()
+        self._ts_encoder = RnnEncoder()
         self._ts_encoder._pytorch_wrapper = list
         self._max_samples = 2000
 
